# -*- coding: iso-8859-15 -*-
# -*- Mode: Python; py-ident-offset: 4 -*-
# vim:ts=4:sw=4:et

# Copyright (c) M�rio Morgado
#
# Redistribution and use in source and binary forms, with or without modification,
# are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice, this
# list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation and/or
# other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
# ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
# ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

'''
rpm definitions
'''

from __future__ import absolute_import

RPM_LEAD_MAGIC_NUMBER = '\xed\xab\xee\xdb'
RPM_HEADER_MAGIC_NUMBER = '\x8e\xad\xe8'

RPMTAG_MIN_NUMBER = 1000
RPMTAG_MAX_NUMBER = 1146

# signature tags
RPMSIGTAG_SIZE = 1000
RPMSIGTAG_LEMD5_1 = 1001
RPMSIGTAG_PGP = 1002
RPMSIGTAG_LEMD5_2 = 1003
RPMSIGTAG_MD5 = 1004
RPMSIGTAG_GPG = 1005
RPMSIGTAG_PGP5 = 1006

MD5_SIZE = 16  # 16 bytes long
PGP_SIZE = 152  # 152 bytes long

# data types definition
RPM_DATA_TYPE_NULL = 0
RPM_DATA_TYPE_CHAR = 1
RPM_DATA_TYPE_INT8 = 2
RPM_DATA_TYPE_INT16 = 3
RPM_DATA_TYPE_INT32 = 4
RPM_DATA_TYPE_INT64 = 5
RPM_DATA_TYPE_STRING = 6
RPM_DATA_TYPE_BIN = 7
# these types are not really standard, 8 and 9 were used for strings in the past
# rpm3 defines these this way
RPM_DATA_TYPE_STRING_ARRAY = 8  # entries with multiple strings
RPM_DATA_TYPE_I18NSTRING_TYPE = 9  # internationalized string
# new types, not yet supported, though said to be handled as binary
RPM_DATA_TYPE_ASN1 = 10
RPM_DATA_TYPE_OPENPGP = 11

RPM_DATA_TYPES = (RPM_DATA_TYPE_NULL,
                  RPM_DATA_TYPE_CHAR,
                  RPM_DATA_TYPE_INT8,
                  RPM_DATA_TYPE_INT16,
                  RPM_DATA_TYPE_INT32,
                  RPM_DATA_TYPE_INT64,
                  RPM_DATA_TYPE_STRING,
                  RPM_DATA_TYPE_BIN,
                  RPM_DATA_TYPE_STRING_ARRAY,
                  RPM_DATA_TYPE_I18NSTRING_TYPE,
                  RPM_DATA_TYPE_ASN1,
                  RPM_DATA_TYPE_OPENPGP
                  )

# tags to collect

RPMTAG_NAME = 1000
RPMTAG_VERSION = 1001
RPMTAG_RELEASE = 1002
RPMTAG_EPOCH = 1003
RPMTAG_SUMMARY = 1004
RPMTAG_DESCRIPTION = 1005
RPMTAG_DISTRIBUTION = 1010
RPMTAG_VENDOR = 1011
RPMTAG_LICENSE = 1014
RPMTAG_PACKAGER = 1015
RPMTAG_GROUP = 1016
RPMTAG_PATCH = 1019
RPMTAG_URL = 1020
RPMTAG_OS = 1021
RPMTAG_ARCH = 1022
RPMTAG_SOURCERPM = 1044
RPMTAG_SOURCEPACKAGE = 1106
RPMTAG_DISTURL = 1123

RPMTAGS = {
   RPMTAG_NAME: 'name',
   RPMTAG_EPOCH: 'epoch',
   RPMTAG_VERSION: 'version',
   RPMTAG_RELEASE: 'release',
   RPMTAG_SUMMARY: 'summary',
   RPMTAG_DESCRIPTION: 'description',
   RPMTAG_DISTRIBUTION: 'distribution',
   RPMTAG_VENDOR: 'vendor',
   RPMTAG_LICENSE: 'license',
   RPMTAG_PACKAGER: 'packager',
   RPMTAG_GROUP: 'group',
   RPMTAG_PATCH: 'patch',
   RPMTAG_URL: 'url',
   RPMTAG_OS: 'os',
   RPMTAG_ARCH: 'arch',
   RPMTAG_SOURCERPM: 'source_rpm',
   RPMTAG_SOURCEPACKAGE: 'source_package',
   RPMTAG_DISTURL: 'dist_url',
}

"""
from rpm.org lib/rpmtag.h
See also: http://refspecs.linuxfoundation.org/LSB_5.0.0/LSB-Core-generic/LSB-Core-generic/pkgformat.html
The one with a # are useful ones.
enum      rpmTag_e {
RPMTAG_HEADERIMAGE = 61,
RPMTAG_HEADERSIGNATURES = 62,
RPMTAG_HEADERIMMUTABLE = 63,
RPMTAG_HEADERREGIONS = 64,
RPMTAG_HEADERI18NTABLE = 100,
#RPMTAG_NAME = 1000,
#RPMTAG_VERSION = 1001,
#RPMTAG_RELEASE = 1002,
RPMTAG_EPOCH = 1003,
#RPMTAG_SUMMARY = 1004,
#RPMTAG_DESCRIPTION = 1005,
#RPMTAG_BUILDTIME = 1006,
#RPMTAG_BUILDHOST = 1007,
RPMTAG_INSTALLTIME = 1008,
RPMTAG_SIZE = 1009,
#RPMTAG_DISTRIBUTION = 1010,
#RPMTAG_VENDOR = 1011,
RPMTAG_GIF = 1012,
RPMTAG_XPM = 1013,
#RPMTAG_LICENSE = 1014, note: aka COPYRIGHT in some cases
#RPMTAG_PACKAGER = 1015,
#RPMTAG_GROUP = 1016,
#RPMTAG_CHANGELOG = 1017,
#RPMTAG_SOURCE = 1018,
#RPMTAG_PATCH = 1019,
#RPMTAG_URL = 1020,
#RPMTAG_OS = 1021,
#RPMTAG_ARCH = 1022,
RPMTAG_PREIN = 1023,
RPMTAG_POSTIN = 1024,
RPMTAG_PREUN = 1025,
RPMTAG_POSTUN = 1026,
RPMTAG_OLDFILENAMES = 1027,
RPMTAG_FILESIZES = 1028,
RPMTAG_FILESTATES = 1029,
RPMTAG_FILEMODES = 1030,
RPMTAG_FILEUIDS = 1031,
RPMTAG_FILEGIDS = 1032,
RPMTAG_FILERDEVS = 1033,
RPMTAG_FILEMTIMES = 1034,
RPMTAG_FILEDIGESTS = 1035,
RPMTAG_FILELINKTOS = 1036,
RPMTAG_FILEFLAGS = 1037,
RPMTAG_ROOT = 1038,
RPMTAG_FILEUSERNAME = 1039,
RPMTAG_FILEGROUPNAME = 1040,
RPMTAG_EXCLUDE = 1041,
RPMTAG_EXCLUSIVE = 1042,
RPMTAG_ICON = 1043,
#RPMTAG_SOURCERPM = 1044,
RPMTAG_FILEVERIFYFLAGS = 1045,
RPMTAG_ARCHIVESIZE = 1046,
RPMTAG_PROVIDENAME = 1047,
RPMTAG_REQUIREFLAGS = 1048,
RPMTAG_REQUIRENAME = 1049,
RPMTAG_REQUIREVERSION = 1050,
#RPMTAG_NOSOURCE = 1051,
#RPMTAG_NOPATCH = 1052,
RPMTAG_CONFLICTFLAGS = 1053,
RPMTAG_CONFLICTNAME = 1054,
RPMTAG_CONFLICTVERSION = 1055,
RPMTAG_DEFAULTPREFIX = 1056,
RPMTAG_BUILDROOT = 1057,
RPMTAG_INSTALLPREFIX = 1058,
RPMTAG_EXCLUDEARCH = 1059,
RPMTAG_EXCLUDEOS = 1060,
RPMTAG_EXCLUSIVEARCH = 1061,
RPMTAG_EXCLUSIVEOS = 1062,
RPMTAG_AUTOREQPROV = 1063,
RPMTAG_RPMVERSION = 1064,
RPMTAG_TRIGGERSCRIPTS = 1065,
RPMTAG_TRIGGERNAME = 1066,
RPMTAG_TRIGGERVERSION = 1067,
RPMTAG_TRIGGERFLAGS = 1068,
RPMTAG_TRIGGERINDEX = 1069,
RPMTAG_VERIFYSCRIPT = 1079,
RPMTAG_CHANGELOGTIME = 1080,
RPMTAG_CHANGELOGNAME = 1081,
RPMTAG_CHANGELOGTEXT = 1082,
RPMTAG_BROKENMD5 = 1083,
RPMTAG_PREREQ = 1084,
RPMTAG_PREINPROG = 1085,
RPMTAG_POSTINPROG = 1086,
RPMTAG_PREUNPROG = 1087,
RPMTAG_POSTUNPROG = 1088,
RPMTAG_BUILDARCHS = 1089,
RPMTAG_OBSOLETENAME = 1090,
RPMTAG_VERIFYSCRIPTPROG = 1091,
RPMTAG_TRIGGERSCRIPTPROG = 1092,
RPMTAG_DOCDIR = 1093,
RPMTAG_COOKIE = 1094,
RPMTAG_FILEDEVICES = 1095,
RPMTAG_FILEINODES = 1096,
RPMTAG_FILELANGS = 1097,
RPMTAG_PREFIXES = 1098,
RPMTAG_INSTPREFIXES = 1099,
RPMTAG_TRIGGERIN = 1100,
RPMTAG_TRIGGERUN = 1101,
RPMTAG_TRIGGERPOSTUN = 1102,
RPMTAG_AUTOREQ = 1103,
RPMTAG_AUTOPROV = 1104,
RPMTAG_CAPABILITY = 1105,
RPMTAG_SOURCEPACKAGE = 1106,
RPMTAG_OLDORIGFILENAMES = 1107,
RPMTAG_BUILDPREREQ = 1108,
RPMTAG_BUILDREQUIRES = 1109,
RPMTAG_BUILDCONFLICTS = 1110,
RPMTAG_BUILDMACROS = 1111,
RPMTAG_PROVIDEFLAGS = 1112,
RPMTAG_PROVIDEVERSION = 1113,
RPMTAG_OBSOLETEFLAGS = 1114,
RPMTAG_OBSOLETEVERSION = 1115,
RPMTAG_DIRINDEXES = 1116,
RPMTAG_BASENAMES = 1117,
RPMTAG_DIRNAMES = 1118,
RPMTAG_ORIGDIRINDEXES = 1119,
RPMTAG_ORIGBASENAMES = 1120,
RPMTAG_ORIGDIRNAMES = 1121,
RPMTAG_OPTFLAGS = 1122,
#RPMTAG_DISTURL = 1123,
RPMTAG_PAYLOADFORMAT = 1124,
RPMTAG_PAYLOADCOMPRESSOR = 1125,
RPMTAG_PAYLOADFLAGS = 1126,
RPMTAG_INSTALLCOLOR = 1127,
RPMTAG_INSTALLTID = 1128,
RPMTAG_REMOVETID = 1129,
RPMTAG_SHA1RHN = 1130,
RPMTAG_RHNPLATFORM = 1131,
RPMTAG_PLATFORM = 1132,
RPMTAG_PATCHESNAME = 1133,
RPMTAG_PATCHESFLAGS = 1134,
RPMTAG_PATCHESVERSION = 1135,
RPMTAG_CACHECTIME = 1136,
RPMTAG_CACHEPKGPATH = 1137,
RPMTAG_CACHEPKGSIZE = 1138,
RPMTAG_CACHEPKGMTIME = 1139,
RPMTAG_FILECOLORS = 1140,
RPMTAG_FILECLASS = 1141,
RPMTAG_CLASSDICT = 1142,
RPMTAG_FILEDEPENDSX = 1143,
RPMTAG_FILEDEPENDSN = 1144,
RPMTAG_DEPENDSDICT = 1145,
RPMTAG_SOURCEPKGID = 1146,
RPMTAG_FILECONTEXTS = 1147,
RPMTAG_FSCONTEXTS = 1148,
RPMTAG_RECONTEXTS = 1149,
RPMTAG_POLICIES = 1150,
RPMTAG_PRETRANS = 1151,
RPMTAG_POSTTRANS = 1152,
RPMTAG_PRETRANSPROG = 1153,
RPMTAG_POSTTRANSPROG = 1154,
RPMTAG_DISTTAG = 1155,
RPMTAG_SUGGESTSNAME = 1156,
RPMTAG_SUGGESTSVERSION = 1157,
RPMTAG_SUGGESTSFLAGS = 1158,
RPMTAG_ENHANCESNAME = 1159,
RPMTAG_ENHANCESVERSION = 1160,
RPMTAG_ENHANCESFLAGS = 1161,
RPMTAG_PRIORITY = 1162,
RPMTAG_CVSID = 1163,
RPMTAG_BLINKPKGID = 1164,
RPMTAG_BLINKHDRID = 1165,
RPMTAG_BLINKNEVRA = 1166,
RPMTAG_FLINKPKGID = 1167,
RPMTAG_FLINKHDRID = 1168,
RPMTAG_FLINKNEVRA = 1169,
RPMTAG_PACKAGEORIGIN = 1170,
RPMTAG_TRIGGERPREIN = 1171,
RPMTAG_BUILDSUGGESTS = 1172,
RPMTAG_BUILDENHANCES = 1173,
RPMTAG_SCRIPTSTATES = 1174,
RPMTAG_SCRIPTMETRICS = 1175,
RPMTAG_BUILDCPUCLOCK = 1176,
RPMTAG_FILEDIGESTALGO = 1177,
RPMTAG_VARIANTS = 1178,
RPMTAG_XMAJOR = 1179,
RPMTAG_XMINOR = 1180,
RPMTAG_REPOTAG = 1181,
#RPMTAG_KEYWORDS = 1182,
RPMTAG_BUILDPLATFORMS = 1183,
RPMTAG_PACKAGECOLOR = 1184,
RPMTAG_PACKAGEPREFCOLOR = 1185,
RPMTAG_XATTRSDICT = 1186,
RPMTAG_FILEXATTRSX = 1187,
RPMTAG_DEPATTRSDICT = 1188,
RPMTAG_CONFLICTATTRSX = 1189,
RPMTAG_OBSOLETEATTRSX = 1190,
RPMTAG_PROVIDEATTRSX = 1191,
RPMTAG_REQUIREATTRSX = 1192,
RPMTAG_BUILDPROVIDES = 1193,
RPMTAG_BUILDOBSOLETES = 1194,
RPMTAG_FILENAMES = 5000,
RPMTAG_FILEPROVIDE = 5001,
RPMTAG_FILEREQUIRE = 5002,
RPMTAG_FSNAMES = 5003,
RPMTAG_FSSIZES = 5004,
RPMTAG_TRIGGERCONDS = 5005,
RPMTAG_TRIGGERTYPE = 5006,
RPMTAG_ORIGFILENAMES = 5007,
RPMTAG_LONGFILESIZES = 5008,
RPMTAG_LONGSIZE = 5009, }
"""
